pub async fn run_cli(system: ActorSystem) -> Result<()>Expand description
Start the interactive CLI loop.
Reads from stdin asynchronously and dispatches messages to system.
Returns when the user types /quit or stdin is closed.
pub async fn run_cli(system: ActorSystem) -> Result<()>Start the interactive CLI loop.
Reads from stdin asynchronously and dispatches messages to system.
Returns when the user types /quit or stdin is closed.